Module: ActionView::Helpers::FormTagHelper

Defined in:
lib/textile_editor_helper.rb

Instance Method Summary collapse

Instance Method Details

#textile_editor_tag(name, content = nil, options = {}) ⇒ Object

Creates a text input area; use a textarea for longer text inputs such as blog posts or descriptions and includes the textile toolbar above it.

Options

  • :size - A string specifying the dimensions (columns by rows) of the textarea (e.g., "25x10").
  • :rows - Specify the number of rows in the textarea
  • :cols - Specify the number of columns in the textarea
  • :disabled - If set to true, the user will not be able to use this input.
  • Any other key creates standard HTML attributes for the tag.

Examples

textile_editor_tag 'post'

=>

textile_editor_tag 'bio', @user.bio

=>

textile_editor_tag 'body', nil, :rows => 10, :cols => 25

=>

textile_editor_tag 'body', nil, :size => "25x10"

=>

textile_editor_tag 'description', "Description goes here.", :disabled => true

=>

textile_editor_tag 'comment', nil, :class => 'comment_input'

=>



175
176
177
178
179
180
181
# File 'lib/textile_editor_helper.rb', line 175

def textile_editor_tag(name, content = nil, options = {})
  editor_id = options[:id] || name
  mode = options.delete(:simple) ? 'simple' : 'extended'
  (@textile_editor_ids ||= []) << [editor_id.to_s, mode.to_s]
  
  text_area_tag(name, content, options)
end